@@ -103,9 +103,9 @@ pub fn parse_token(
                 "destination": account_keys[instruction.accounts[1] as usize].to_string(),
                 "amount": amount.to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -124,9 +124,9 @@ pub fn parse_token(
                 "delegate": account_keys[instruction.accounts[1] as usize].to_string(),
                 "amount": amount.to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -143,9 +143,9 @@ pub fn parse_token(
             let mut value = json!({
                 "source": account_keys[instruction.accounts[0] as usize].to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 1,
                 account_keys,
                 &instruction.accounts,
@@ -174,9 +174,9 @@ pub fn parse_token(
                     COption::None => None,
                 },
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 1,
                 account_keys,
                 &instruction.accounts,
@@ -195,9 +195,9 @@ pub fn parse_token(
                 "account": account_keys[instruction.accounts[1] as usize].to_string(),
                 "amount": amount.to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -216,9 +216,9 @@ pub fn parse_token(
                 "mint": account_keys[instruction.accounts[1] as usize].to_string(),
                 "amount": amount.to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -236,9 +236,9 @@ pub fn parse_token(
                 "account": account_keys[instruction.accounts[0] as usize].to_string(),
                 "destination": account_keys[instruction.accounts[1] as usize].to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -256,9 +256,9 @@ pub fn parse_token(
                 "account": account_keys[instruction.accounts[0] as usize].to_string(),
                 "mint": account_keys[instruction.accounts[1] as usize].to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -276,9 +276,9 @@ pub fn parse_token(
                 "account": account_keys[instruction.accounts[0] as usize].to_string(),
                 "mint": account_keys[instruction.accounts[1] as usize].to_string(),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -298,9 +298,9 @@ pub fn parse_token(
                 "destination": account_keys[instruction.accounts[2] as usize].to_string(),
                 "tokenAmount": token_amount_to_ui_amount(amount, decimals),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 3,
                 account_keys,
                 &instruction.accounts,
@@ -320,9 +320,9 @@ pub fn parse_token(
                 "delegate": account_keys[instruction.accounts[2] as usize].to_string(),
                 "tokenAmount": token_amount_to_ui_amount(amount, decimals),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 3,
                 account_keys,
                 &instruction.accounts,
@@ -341,9 +341,9 @@ pub fn parse_token(
                 "account": account_keys[instruction.accounts[1] as usize].to_string(),
                 "tokenAmount": token_amount_to_ui_amount(amount, decimals),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
@@ -362,9 +362,9 @@ pub fn parse_token(
                 "mint": account_keys[instruction.accounts[1] as usize].to_string(),
                 "tokenAmount": token_amount_to_ui_amount(amount, decimals),
             });
-            let mut map = value.as_object_mut().unwrap();
+            let map = value.as_object_mut().unwrap();
             parse_signers(
-                &mut map,
+                map,
                 2,
                 account_keys,
                 &instruction.accounts,
